Django GeoIP
============

.. image:: https://secure.travis-ci.org/coagulant/django-geoip.png?branch=dev

App to figure out where your visitors are from by their IP address.

Tha app is early alpha, beware.

Docs: http://django-geoip.readthedocs.org/